@@ -197,90 +197,92 @@ class WellCorrelation:
             initialization. Otherwise a linear aggregation depending on ``min_seg`` is used.
 
         """
-        self.match_column = match_column
-        self.depth_column = depth_column
-        self.min_seg = min_seg
-        self.pelt_sup = pelt_sup
-        self.quantiles_list = quantile_list
-        self.lr_normalize = lr_normalize
+        self._match_column = match_column
+        self._depth_column = depth_column
+        self._min_seg = min_seg
+        self._pelt_sup = pelt_sup
+        self._quantiles_list = quantile_list
+        self._lr_normalize = lr_normalize
 
         self.__PENALTY_PELT = int(1e-8)
         self.__CONSENSUS_per = 0.5
 
         # Reference log value associated to each alphabet item
-        self.value_alphabet = pd.DataFrame({"alphabet": [], "quantile": []})
+        self._value_alphabet = pd.DataFrame({"alphabet": [], "quantile": []})
         # Well log sequence, as a list of Bio.SeqRecord.SeqRecord
-        self.sequence_logs = []
+        self._sequence_logs = []
         # Well log multi-sequence alignment, as a skbio.TabularMSA
-        self.multi_sequence_alignment = TabularMSA("")
+        self._multi_sequence_alignment = TabularMSA("")
         # Dictionnary matching the letter in the alignment with the depth for each well
-        self.depth_match_global = {}
+        self._depth_match_global = {}
         # Consensus
         self.consensus = pd.DataFrame(
-            {self.match_column: [], self.depth_column: [], "freq": []}
+            {self._match_column: [], self._depth_column: [], "freq": []}
         )
         # Markers
         self.markers = pd.DataFrame(
-            {self.depth_column: [], "marker_name": [], "hole_id": []}
+            {self._depth_column: [], "marker_name": [], "hole_id": []}
         )
 
         # For each well of the site of interest, compute normalized version of data series
         # The normalization is done by considering local mean values, depending on:
         # - the PELT algorithm (fancy version), see pelt, __PENALTY_PELT and min_seg attributes
         # - or on a fixed step (simple version), see min_seg attribute
-        self.dict_data = {}
-        self.dict_data_original = {}
-        self.dict_segmentation = {}
+        self._dict_data = {}
+        self._dict_data_original = {}
+        self._dict_segmentation = {}
         for idx_well, well_data in data_log.groupby(well_column):
 
             well_name = str(well_data[well_column].iloc[0])
-            well_data.set_index(self.depth_column, inplace=True)
+            well_data.set_index(self._depth_column, inplace=True)
             well_data = well_data.loc[
                 (depth_min < well_data.index)
                 & (well_data.index < depth_max)
-                & (value_min < well_data[self.match_column])
-                & (well_data[self.match_column] < value_max)
+                & (value_min < well_data[self._match_column])
+                & (well_data[self._match_column] < value_max)
             ].copy()
             well_data.dropna(inplace=True)
             # Depending on log_normalize parameter, consider logarithmic values
             if log_normalize:
-                well_data[self.match_column] = np.log(well_data[self.match_column])
+                well_data[self._match_column] = np.log(well_data[self._match_column])
             # Define the raw data series for this well
-            self.dict_data_original[well_name] = well_data
+            self._dict_data_original[well_name] = well_data
 
             # If pelt is True, this algorithm is run to extract segmentation sequence
             if segmentize_with_pelt:
                 scaled_data = pd.DataFrame(
-                    preprocessing.scale(well_data[[self.match_column]])
+                    preprocessing.scale(well_data[[self._match_column]])
                 )
                 seg_match_small = pelt_ordered_indices(
-                    scaled_data, self.__PENALTY_PELT, self.min_seg
+                    scaled_data, self.__PENALTY_PELT, self._min_seg
                 )
             # Otherwise, one uses a regular sampling sequence
             else:
                 seg_match_small = np.arange(
-                    0, len(well_data[[self.match_column]]), self.min_seg
+                    0, len(well_data[[self._match_column]]), self._min_seg
                 ).astype(int)
-            self.dict_segmentation[well_name] = seg_match_small
+            self._dict_segmentation[well_name] = seg_match_small
 
             # Compute the normalized version of dataseries, knowing the segmentation sequence
             mean_query = compute_mean_segmentation(
-                well_data[[self.match_column]].values, seg_match_small
+                well_data[[self._match_column]].values, seg_match_small
             )
             # Define the preprocess data series for this well
-            self.dict_data[well_name] = pd.DataFrame({self.match_column: (mean_query)})
+            self._dict_data[well_name] = pd.DataFrame(
+                {self._match_column: (mean_query)}
+            )
 
     @property
-    def sequence_filepath(self):
+    def _sequence_filepath(self):
         return FAMSA_PATH / "short_seqs.fasta"
 
     @property
-    def famsa_output_filepath(self):
+    def _famsa_output_filepath(self):
         return FAMSA_PATH / "result_famsa.fasta"
 
     @property
-    def vect_alphabet(self):
-        return DNA_ALPHABET_SEQUENCE[: 1 + len(self.quantiles_list)]
+    def _vect_alphabet(self):
+        return DNA_ALPHABET_SEQUENCE[: 1 + len(self._quantiles_list)]
 
     def run(self):
         """Run the full well correlation pipeline so as to generate consensus logs and markers for each
@@ -291,7 +293,7 @@ class WellCorrelation:
         self.run_famsa()
         self.compute_depth_match()
         self.compute_consensus()
-        self.compute_markers(self.tops_algn_position)
+        self.compute_markers(self._marker_index_global)
 
     def prepare_logs(self):
         """Prepare data logs: starting from segmented version of dataseries for each well, generate letter
@@ -301,13 +303,13 @@ class WellCorrelation:
         letter with a data quantiles.
 
         """
-        if self.sequence_filepath.is_file():
-            self.sequence_filepath.unlink()
+        if self._sequence_filepath.is_file():
+            self._sequence_filepath.unlink()
         # Concatenate the normalized data and generate the quantiles of the resulting series
         all_squared_data = pd.concat(
-            [dd[self.match_column] for _, dd in self.dict_data.items()]
+            [dd[self._match_column] for _, dd in self._dict_data.items()]
         ).reset_index(drop=True)
-        global_quantiles = all_squared_data.quantile(self.quantiles_list).values
+        global_quantiles = all_squared_data.quantile(self._quantiles_list).values
 
         # The quantile vector is redefined with extrem quantiles.
         # From now one considers the center of each histogram class.
@@ -321,8 +323,8 @@ class WellCorrelation:
         global_quantiles_vect_value = (
             np.diff(extended_quantiles) / 2 + extended_quantiles[:-1]
         )
-        self.value_alphabet = pd.DataFrame(
-            {"alphabet": self.vect_alphabet, "quantile": global_quantiles_vect_value}
+        self._value_alphabet = pd.DataFrame(
+            {"alphabet": self._vect_alphabet, "quantile": global_quantiles_vect_value}
         ).set_index("alphabet")
 
         # Prepare RNA sequence logs
@@ -330,31 +332,33 @@ class WellCorrelation:
         lr = linear_model.LinearRegression()
 
         # For each well (and corresponding data), transcribe the dataseries with reference alphabet
-        for key, well in self.dict_data.items():
+        for key, well in self._dict_data.items():
 
             # If normalize is True, a normalized version of values are generated
             # using a linear regression over quantiles
-            if self.lr_normalize:
+            if self._lr_normalize:
                 lr.fit(
-                    well[self.match_column]
-                    .quantile(self.quantiles_list)
+                    well[self._match_column]
+                    .quantile(self._quantiles_list)
                     .values.reshape(-1, 1),
                     global_quantiles.reshape(-1, 1),
                 )
-                well[self.match_column + "_norm"] = lr.predict(
-                    well[[self.match_column]]
+                well[self._match_column + "_norm"] = lr.predict(
+                    well[[self._match_column]]
                 )
             else:
-                well[self.match_column + "_norm"] = well[[self.match_column]]
+                well[self._match_column + "_norm"] = well[[self._match_column]]
 
             sequence = custom_SAX(
-                well[self.match_column + "_norm"],
+                well[self._match_column + "_norm"],
                 global_quantiles,
-                self.vect_alphabet,
+                self._vect_alphabet,
+            )
+            self._sequence_logs.append(
+                SeqRecord(Seq(sequence), id=key, description=key)
             )
-            self.sequence_logs.append(SeqRecord(Seq(sequence), id=key, description=key))
         # Write sequences on a fasta file
-        SeqIO.write(self.sequence_logs, self.sequence_filepath, "fasta")
+        SeqIO.write(self._sequence_logs, self._sequence_filepath, "fasta")
 
     def run_famsa(self):
         """Run the FAMSA program in order to generate multi aligned sequences of log measures
@@ -364,16 +368,16 @@ class WellCorrelation:
 
         """
         # If famsa output file exists on the file system, remove it
-        if self.famsa_output_filepath.is_file():
-            self.famsa_output_filepath.unlink()
+        if self._famsa_output_filepath.is_file():
+            self._famsa_output_filepath.unlink()
         # Run FAMSA program starting from the previously generated sequence file
-        if not self.sequence_filepath.is_file():
+        if not self._sequence_filepath.is_file():
             logger.info(
                 "Input fasta sequence file (%s) does not exist, let's prepare it...",
-                self.sequence_filepath,
+                self._sequence_filepath,
             )
             self.prepare_logs()
-        logger.info("Run FAMSA program on %s.", self.sequence_filepath)
+        logger.info("Run FAMSA program on %s.", self._sequence_filepath)
         subprocess.call(
             [
                 "famsa",
@@ -383,12 +387,12 @@ class WellCorrelation:
                 "5",
                 "-r",
                 "100",
-                str(self.sequence_filepath),
-                str(self.famsa_output_filepath),
+                str(self._sequence_filepath),
+                str(self._famsa_output_filepath),
             ]
         )
         # Import alignment
-        self.multi_sequence_alignment = read(
+        self._multi_sequence_alignment = read(
             str(FAMSA_PATH / "result_famsa.fasta"),
             format="fasta",
             into=TabularMSA,
@@ -401,12 +405,12 @@ class WellCorrelation:
 
         """
         # Set depth match global for each well
-        self.df_align = {}
-        for key, data in self.dict_data_original.items():
+        self._df_align = {}
+        for key, data in self._dict_data_original.items():
             # Extract DNA sequences as strings for each well
             sequence = [
                 str(protein)
-                for protein in self.multi_sequence_alignment
+                for protein in self._multi_sequence_alignment
                 if protein.metadata["id"] == key
             ]
             assert len(sequence) == 1
@@ -419,60 +423,61 @@ class WellCorrelation:
             df_align["indices"] = (
                 df_align["indices"].fillna(method="ffill").astype("int")
             )
-            self.df_align[key] = df_align["indices"].values
+            self._df_align[key] = df_align["indices"].values
             # Here one gets non-empty letter indices,
             # one builds depth_match_global item starting from raw data
-            seg_match = self.dict_segmentation[key][df_align["indices"].values]
-            self.depth_match_global[key] = np.array(data.index[seg_match])
+            seg_match = self._dict_segmentation[key][df_align["indices"].values]
+            self._depth_match_global[key] = np.array(data.index[seg_match])
 
     def compute_consensus(self):
         """Compute the consensus log, which is a "mean" log that aggregates the logs from every well. This
-        method also sets the value of tops_algn_position, which represents a raw marker set
+        method also sets the value of marker_index_global, which represents a raw marker set
 
         This method calls the PELT algorithm, developed in pychangepoints dependency.
         """
         # Prepare a DataFrame version of the alignment, with wells as indices
-        df_msa = pd.DataFrame(self.multi_sequence_alignment.to_dict())
+        df_msa = pd.DataFrame(self._multi_sequence_alignment.to_dict())
         df_msa.loc[:] = df_msa.values.astype(str)
         df_msa.columns = [
-            protein.metadata["id"] for protein in self.multi_sequence_alignment
+            protein.metadata["id"] for protein in self._multi_sequence_alignment
         ]
         # Compute letter frequency, for each position of the dataseries
         freq_df = df_msa.apply(pd.value_counts, axis=1)
-        letter_frequency = freq_df[self.vect_alphabet].sum(axis=1)
+        letter_frequency = freq_df[self._vect_alphabet].sum(axis=1)
         # Building consensus series: an index belongs to the consensus
         # if there is data on a significative (see __CONSENSUS_per attribute) part of wells
         mask_consensus = letter_frequency > (1 - self.__CONSENSUS_per) * df_msa.shape[1]
         consensus = (
-            freq_df.drop(columns="-").fillna(0).dot(self.value_alphabet["quantile"])
+            freq_df.drop(columns="-").fillna(0).dot(self._value_alphabet["quantile"])
             / letter_frequency
         )
         self.consensus = pd.DataFrame(
             {
-                self.match_column: np.repeat(consensus[mask_consensus], self.min_seg),
-                self.depth_column: np.linspace(
+                self._match_column: np.repeat(consensus[mask_consensus], self._min_seg),
+                self._depth_column: np.linspace(
                     0, mask_consensus.sum() - 1, mask_consensus.sum()
                 )
                 / 10,
                 "freq": np.repeat(
-                    letter_frequency[mask_consensus] / df_msa.shape[1], self.min_seg
+                    letter_frequency[mask_consensus] / df_msa.shape[1], self._min_seg
                 ),
             }
         )
-        self.consensus.set_index(self.depth_column, inplace=True)
-        self.index_global_consensus = consensus[mask_consensus].index.values
+        self.consensus.set_index(self._depth_column, inplace=True)
+        self._index_global_consensus = consensus[mask_consensus].index.values
         # Segmentize the consensus log to build the chronicle of aligned tops
         scaled_data = pd.DataFrame(
-            preprocessing.scale(self.consensus[self.match_column])
+            preprocessing.scale(self.consensus[self._match_column])
         )
-        seg_signal = pelt_ordered_indices(scaled_data, 2, self.pelt_sup)
-        self.tops_algn_position = np.unique(
-            self.index_global_consensus[seg_signal // self.min_seg]
+        seg_signal = pelt_ordered_indices(scaled_data, 2, self._pelt_sup)
+        self.marker_index_in_consensus = seg_signal // self._min_seg
+        self._marker_index_global = np.unique(
+            self._index_global_consensus[self.marker_index_in_consensus]
         ).astype(int)
 
-    def extract_top_indices(self, tops):
-        """Given a list of depth positions, compute the corresponding indices in the consensus log. This
-        function aims at providing a valid input parameter for ``compute_markers`` method.
+    def extract_marker_indices(self, tops):
+        """Given a list of depths, compute the corresponding indices in the consensus log. This function
+        aims at providing a valid input parameter for ``compute_markers`` method.
 
         If the input list contains values that are not in consensus depth axis, these values are
         not considered.
@@ -486,7 +491,7 @@ class WellCorrelation:
         """
         mask = self.consensus.index.isin(tops)
         idx_consensus = self.consensus.reset_index().loc[mask].index
-        return self.index_global_consensus[idx_consensus]
+        return self._index_global_consensus[idx_consensus]
 
     def compute_markers(self, aligned_positions):
         """Compute the final state of markers associated to the well set
@@ -498,8 +503,8 @@ class WellCorrelation:
         """
         # Finding the consensus marker for each well
         list_tops = []
-        for key in self.dict_data:
-            tops_current = self.depth_match_global[key][aligned_positions]
+        for key in self._dict_data:
+            tops_current = self._depth_match_global[key][aligned_positions]
             # Filter duplicated values at the beginning of the marker chronicle
             m_tot = len(tops_current) - 1
             i_j = 1
